@@ -56,7 +56,7 @@ void Titraqform::loadAccounts(QFile &Fileobj)
     }
     else {
         if (!Fileobj.open(IO_ReadOnly)) // Try to open file
-            throw Genexcept("Could not open account file.");
+            throw Genexcept("Could not open account file for reading.");
         else
             Fileobj.flush();                // Begin processing file cleanly
             QTextStream Account(&Fileobj);  // Convert data to stream
@@ -122,7 +122,7 @@ void Titraqform::loadData(QFile &Fileobj)
     }
     else {
         if (!Fileobj.open(IO_ReadOnly)) // Try to open file
-            throw Genexcept("Could not open personal data file.");
+            throw Genexcept("Could not open personal data file for reading.");
         else
             Fileobj.flush();                // Begin processing file cleanly
             QTextStream Asentry(&Fileobj);  // Convert data to stream
@@ -287,7 +287,7 @@ void Titraqform::saveData(QFile &Fileobj)
     }
     else {
         if (!Fileobj.open(IO_WriteOnly)) // Try to open file
-            throw Genexcept("Could not write open accounting file.");
+            throw Genexcept("Could not open personal data file for writing.");
         QTextStream Asentry(&Fileobj);  // Convert data to stream
         this->saveData(Asentry);        // Pass off to do the real work
         Fileobj.close();                // Finish fileop by closing
