@@ -95,6 +95,7 @@ public:
     QAction     *m_pFilesaveact,  *m_pFilesaveasact;
     QAction     *m_pFilecloseact, *m_pFilequitact;
     QAction     *m_pAddrowact,    *m_pDelrowact;
+    QAction     *m_pRefreshact;
     QAction     *m_pCutact,       *m_pCopyact;
     QAction     *m_pPasteact,     *m_pWritedataact;
 
@@ -124,6 +125,7 @@ protected slots:
     void pasteEntry(void);              // Paste task entries to the list
     void addEntry(int nRows= -1);       // Add task entries to the list
     void delEntry(int nRows= -1);       // Delete task entries from the list
+    void refreshDisplay(void);          // Refresh the display of all data items
     void newDoc(void);                  // Make and display a new document window
     void openDoc(void);                 // Open and display an existing document
     void saveFile(void);                // Serialize to the current file
@@ -156,6 +158,7 @@ protected slots:
     void timingView(void);              // View menu timing
     void showFilebar(void);             // View menu show file toolbar
     void showEditbar(void);             // View menu show edit toolbar
+    void showViewbar(void);             // View menu show view toolbar
     void showWhatsbar(void);            // View menu show whats this toolbar
     void showStatcol(void);             // View menu show status column
     void showLinecol(void);             // View menu show line numbers column
@@ -192,6 +195,7 @@ private:
     // Belong to us
     QToolBar    *m_pFiletools;
     QToolBar    *m_pEdittools;
+    QToolBar    *m_pViewtools;
     QToolBar    *m_pWhatstools;
     QString     *m_szFilename;
 
@@ -211,8 +215,10 @@ private:
     void setupColumns(void);            // Arrange and configure columns
 
     // Data processing
-    void loadData(QFile &);             // Load accounting data from file
-    void loadData(QTextStream &);       // Load accounting data from stream
+    void loadAccounts(QFile &);         // Load accounts from file
+    void loadAccounts(QTextStream &);   // Load accounts from stream
+    void loadData(QFile &);             // Load personal data from file
+    void loadData(QTextStream &);       // Load personal data from stream
     void saveData(QFile &);             // Save accounting data to file
     void saveData(QTextStream &);       // Save accounting data to stream
 };
