@@ -123,3 +123,41 @@ void TiTable::sortColumn(int nCol, bool bAscend, bool bWhole)
     for (int nIter = this->numRows() - 1; nIter >= 0; nIter--)
         this->setText(nIter, TITRAQ_IDXLINE, QString::number(nIter).rightJustify(4, QChar('0')));
 }
+
+// Overriden member to render edge rows differently according to a sort key
+void TiTable::paintCell(QPainter *pPainter, int nRow, int nCol, const QRect &Recto, bool bSelect, const QColorGroup &Colgroup)
+{
+    QColorGroup Cgroup(Colgroup);
+
+    // Alternate color for nonmatching sort keys
+    QString Cur = this->text(nRow, this->getSortcol());
+    QString Las = this->text(nRow - 1, this->getSortcol());
+
+    // Set the base color conditionally
+    if (!Cur.isNull() && !Las.isNull() && Cur == Las)
+        Cgroup.setColor(QColorGroup::Base, QColor(248, 248, 240));
+    else
+        Cgroup.setColor(QColorGroup::Base, QColor(232, 232, 224));
+
+    QTable::paintCell(pPainter, nRow, nCol, Recto, bSelect, Cgroup);
+};
+
+// Blah
+void TiTable::activateNextCell(void)
+{
+    int nIter = 1; // Logic to skip invisible or read only columns
+    while (columnWidth((currentColumn() + nIter) % TITRAQ_IDXTAIL) <= 0
+        || isColumnReadOnly((currentColumn() + nIter) % TITRAQ_IDXTAIL))
+        nIter++;
+
+    // Advance the column or both row and column possibly
+    int nColadvance = ((currentColumn() + nIter) % TITRAQ_IDXTAIL);
+    if ((currentColumn() + nIter) >= TITRAQ_IDXTAIL)
+        this->setCurrentCell(currentRow() + 1, nColadvance);
+    else
+        this->setCurrentCell(currentRow(), nColadvance);
+    this->setReadOnly(false);
+    this->editCell(currentRow(), currentColumn());
+    this->setEdition(currentColumn());
+    this->setReadOnly(true);
+}
